@@ -18,9 +18,13 @@
 # Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
 
-import os, time, utilist
+from __future__ import absolute_import
+from __future__ import print_function
+import os, time
+from .utilist import bitmasklist
+from six.moves import range
 
-VERSION="0.3"
+VERSION="0.5"
 
 def process_cmdline(pid_info):
 	"""
@@ -119,13 +123,13 @@ class pidstat:
 		return self.fields[fieldname]
 
 	def keys(self):
-		return self.fields.keys()
+		return list(self.fields.keys())
 
 	def values(self):
-		return self.fields.values()
+		return list(self.fields.values())
 
 	def has_key(self, fieldname):
-		return self.fields.has_key(fieldname)
+		return fieldname in self.fields
 
 	def items(self):
 		return self.fields
@@ -252,13 +256,13 @@ class pidstatus:
 		return self.fields[fieldname]
 
 	def keys(self):
-		return self.fields.keys()
+		return list(self.fields.keys())
 
 	def values(self):
-		return self.fields.values()
+		return list(self.fields.values())
 
 	def has_key(self, fieldname):
-		return self.fields.has_key(fieldname)
+		return fieldname in self.fields
 
 	def items(self):
 		return self.fields
@@ -320,7 +324,7 @@ class process:
 		return hasattr(self, attr)
 
 	def load_cmdline(self):
-		f = file("/proc/%d/cmdline" % self.pid)
+		f = open("/proc/%d/cmdline" % self.pid)
 		self.cmdline = f.readline().strip().split('\0')[:-1]
 		f.close()
 
@@ -330,7 +334,7 @@ class process:
 		del self.threads[self.pid]
 
 	def load_cgroups(self):
-		f = file("/proc/%d/cgroup" % self.pid)
+		f = open("/proc/%d/cgroup" % self.pid)
 		self.cgroups = ""
 		for line in reversed(f.readlines()):
 			if len(self.cgroups):
@@ -366,7 +370,7 @@ class process:
 		>>>
 		"""
 		self.environ = {}
-		f = file("/proc/%d/environ" % self.pid)
+		f = open("/proc/%d/environ" % self.pid)
 		for x in f.readline().split('\0'):
 			if len(x) > 0:
 				y = x.split('=')
@@ -397,13 +401,13 @@ class pidstats:
 			pass
 
 	def keys(self):
-		return self.processes.keys()
+		return list(self.processes.keys())
 
 	def values(self):
-		return self.processes.values()
+		return list(self.processes.values())
 
 	def has_key(self, key):
-		return self.processes.has_key(key)
+		return key in self.processes
 
 	def items(self):
 		return self.processes
@@ -569,13 +573,13 @@ class interrupts:
 		return self.interrupts[str(key)]
 
 	def keys(self):
-		return self.interrupts.keys()
+		return list(self.interrupts.keys())
 
 	def values(self):
-		return self.interrupts.values()
+		return list(self.interrupts.values())
 
 	def has_key(self, key):
-		return self.interrupts.has_key(str(key))
+		return str(key) in self.interrupts
 
 	def items(self):
 		return self.interrupts
@@ -623,10 +627,10 @@ class interrupts:
 
 	def parse_affinity(self, irq):
 		try:
-			f = file("/proc/irq/%s/smp_affinity" % irq)
+			f = open("/proc/irq/%s/smp_affinity" % irq)
 			line = f.readline()
 			f.close()
-			return utilist.bitmasklist(line, self.nr_cpus)
+			return bitmasklist(line, self.nr_cpus)
 		except IOError:
 			return [ 0, ]
 
@@ -647,7 +651,7 @@ class interrupts:
 		>>>
 		"""
 		for i in self.interrupts.keys():
-			if self.interrupts[i].has_key("users") and \
+			if "users" in self.interrupts[i] and \
 			   user in self.interrupts[i]["users"]:
 				return i
 		return None
@@ -670,7 +674,7 @@ class interrupts:
 		"""
 		irqs = []
 		for i in self.interrupts.keys():
-			if not self.interrupts[i].has_key("users"):
+			if "users" not in self.interrupts[i]:
 				continue
 			for user in self.interrupts[i]["users"]:
 				if regex.match(user):
@@ -703,7 +707,7 @@ class cmdline:
 		self.parse()
 
 	def parse(self):
-		f = file("/proc/cmdline")
+		f = open("/proc/cmdline")
 		for option in f.readline().strip().split():
 			fields = option.split("=")
 			if len(fields) == 1:
@@ -717,10 +721,10 @@ class cmdline:
 		return self.options[key]
 
 	def keys(self):
-		return self.options.keys()
+		return list(self.options.keys())
 
 	def values(self):
-		return self.options.values()
+		return list(self.options.values())
 
 	def items(self):
 		return self.options
@@ -766,16 +770,16 @@ class cpuinfo:
 		return self.tags[key.lower()]
 
 	def keys(self):
-		return self.tags.keys()
+		return list(self.tags.keys())
 
 	def values(self):
-		return self.tags.values()
+		return list(self.tags.values())
 
 	def items(self):
 		return self.tags
 
 	def parse(self, filename):
-		f = file(filename)
+		f = open(filename)
 		for line in f.readlines():
 			line = line.strip()
 			if len(line) == 0:
@@ -810,7 +814,7 @@ class smaps_lib:
 	"""
 	def __init__(self, lines):
 		fields = lines[0].split()
-		self.vm_start, self.vm_end = map(lambda a: int(a, 16), fields[0].split("-"))
+		self.vm_start, self.vm_end = [int(a, 16) for a in fields[0].split("-")]
 		self.perms = fields[1]
 		self.offset = int(fields[2], 16)
 		self.major, self.minor = fields[3].split(":")
@@ -833,10 +837,10 @@ class smaps_lib:
 		return self.tags[key.lower()]
 
 	def keys(self):
-		return self.tags.keys()
+		return list(self.tags.keys())
 
 	def values(self):
-		return self.tags.values()
+		return list(self.tags.values())
 
 	def items(self):
 		return self.tags
@@ -898,7 +902,7 @@ class smaps:
 		return self.entries[index]
 
 	def reload(self):
-		f = file("/proc/%d/smaps" % self.pid)
+		f = open("/proc/%d/smaps" % self.pid)
 		line = None
 		while True:
 			line = self.parse_entry(f, line)
@@ -968,13 +972,13 @@ class cpusstats:
 		return self.entries[key]
 
 	def __len__(self):
-		return len(self.entries.keys())
+		return len(list(self.entries.keys()))
 
 	def keys(self):
-		return self.entries.keys()
+		return list(self.entries.keys())
 
 	def values(self):
-		return self.entries.values()
+		return list(self.entries.values())
 
 	def items(self):
 		return self.entries
@@ -982,7 +986,7 @@ class cpusstats:
 	def reload(self):
 		last_entries = self.entries
 		self.entries = {}
-		f = file(self.filename)
+		f = open(self.filename)
 		for line in f.readlines():
 			fields = line.strip().split()
 			if fields[0][:3].lower() != "cpu":
@@ -1018,32 +1022,32 @@ if __name__ == '__main__':
 	ints = interrupts()
 
 	for i in ints.interrupts.keys():
-		print "%s: %s" % (i, ints.interrupts[i])
+		print("%s: %s" % (i, ints.interrupts[i]))
 
 	options = cmdline()
 	for o in options.options.keys():
-		print "%s: %s" % (o, options.options[o])
+		print("%s: %s" % (o, options.options[o]))
 
 	cpu = cpuinfo()
-	print "\ncpuinfo data: %d processors" % cpu.nr_cpus
+	print("\ncpuinfo data: %d processors" % cpu.nr_cpus)
 	for tag in cpu.keys():
-		print "%s=%s" % (tag, cpu[tag])
+		print("%s=%s" % (tag, cpu[tag]))
 
-	print "smaps:\n" + ("-" * 40)
+	print("smaps:\n" + ("-" * 40))
 	s = smaps(int(sys.argv[1]))
 	for i in range(s.nr_entries):
-		print "%#x %s" % (s.entries[i].vm_start, s.entries[i].name)
-	print "-" * 40
+		print("%#x %s" % (s.entries[i].vm_start, s.entries[i].name))
+	print("-" * 40)
 	for a in s.find_by_name_fragment(sys.argv[2]):
-		print a["Size"]
+		print(a["Size"])
 
 	ps = pidstats()
-	print ps[1]
+	print(ps[1])
 
 	cs = cpusstats()
 	while True:
 		time.sleep(1)
 		cs.reload()
 		for cpu in cs:
-			print "%s: %d" % (cpu.name, cpu.usage)
-		print "-" * 10
+			print("%s: %d" % (cpu.name, cpu.usage))
+		print("-" * 10)
